@@ -1,4 +1,4 @@
 # Newer Linux versions have ut_host and ut_addr fields
 $self->{CCFLAGS} = $Config{ccflags} . ' -DHAS_UT_HOST -DHAS_UT_ADDR';
 # Linux invention: UT_UNKNOWN instead of EMPTY
-$self->{CCFLAGS} = $Config{ccflags} . ' -DEMPTY=UT_UNKNOWN';
+$self->{CCFLAGS} .= ' -DEMPTY=UT_UNKNOWN';
